Skip to contents

Prepares the components needed for prior specification and estimation. Also computes OLS estimates.

Usage

setup(
  x,
  p = 1,
  deterministic = c("constant", "constant_and_dummy", "constant_and_trend"),
  dummy = NULL
)

Arguments

x

A steady-state bvar object created by bvar.

p

Integer. The lag order of the VAR. Default 1.

deterministic

Character. The deterministic component to include. One of "constant" (default), "constant_and_dummy", or "constant_and_trend".

dummy

Numeric vector of a dummy variable. Only used when deterministic = "constant_and_dummy". Default NULL.

Value

The steady-state bvar object with a setup list containing the required components for prior specification and estimation, and also the OLS estimates.

Examples

yt <- matrix(rnorm(50), 25, 2)

bvar_obj <- bvar(data = yt)

bvar_obj <- setup(bvar_obj)